from dataclasses import dataclass, field
from typing import List, Optional
from xsdata.models.datatype import XmlDateTime
from ExchCommon import ErrorType
from Packet import Packet

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class GetPacketListResponseType:
    """
    :ivar packet_id: Идентификатор транспортного контейнера (GUID), по
        которому его можно получить клиенту
    :ivar time_stamp_last_packet: Метка времени, на которую вернули всю
        актуальную информацию
    """
    packet_id: List[str] = field(
        default_factory=list,
        metadata={
            "name": "PacketID",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    time_stamp_last_packet: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "TimeStampLastPacket",
            "type": "Attribute",
        }
    )


@dataclass
class GetSettingsResponseType:
    """
    :ivar data: Настройки обмена с банком
    :ivar id: Идентификатор настроек
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """
    data: Optional["GetSettingsResponseType.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class Data:
        """
        :ivar value:
        :ivar dockind: Код вида электронного документа, как он задан в
            описаниии к стандарту
        """
        value: Optional[bytes] = field(
            default=None,
            metadata={
                "required": True,
                "format": "base64",
            }
        )
        dockind: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
                "required": True,
                "length": 2,
            }
        )


@dataclass
class LogonCertResponseType:
    """
    :ivar encrypted_sid: Зашифрованный Идентификатор сессии
    """
    encrypted_sid: Optional[bytes] = field(
        default=None,
        metadata={
            "name": "EncryptedSID",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "format": "base64",
        }
    )


@dataclass
class LogonResponseType:
    """
    :ivar sid: Идентификатор сессии
    :ivar extra_auth: Дополнительная аутентификация. Указывается, если
        требуется доп. аутентфикация
    """
    sid: Optional[str] = field(
        default=None,
        metadata={
            "name": "SID",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    extra_auth: Optional["LogonResponseType.ExtraAuth"] = field(
        default=None,
        metadata={
            "name": "ExtraAuth",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )

    @dataclass
    class ExtraAuth:
        """
        :ivar otp: Параметры доп.аутентификации, которые будут
            направляны клиенту
        """
        otp: Optional["LogonResponseType.ExtraAuth.Otp"] = field(
            default=None,
            metadata={
                "name": "OTP",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
            }
        )

        @dataclass
        class Otp:
            """
            :ivar phone_mask: Маска телефона или номер  клиента
            :ivar code: Короткий код сессии, который будет показан при
                вводе OTP
            """
            phone_mask: Optional[str] = field(
                default=None,
                metadata={
                    "name": "phoneMask",
                    "type": "Attribute",
                    "max_length": 12,
                }
            )
            code: Optional[str] = field(
                default=None,
                metadata={
                    "type": "Attribute",
                    "max_length": 10,
                }
            )


@dataclass
class SendPacketResponseType:
    """
    :ivar id: Идентификатор транспортного контейнера (GUID), который был
        ему назначен на стороне банка
    """
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "ID",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )


@dataclass
class SuccessResultType:
    """
    :ivar send_packet_response: Отправка транспортного контейнера в банк
    :ivar get_packet_list_response: Список ID транспортных контейнеров,
        готовых к передачи клиенту
    :ivar get_packet_response: Транспортный контейнер с данными
        электронных документов для получения клиентом
    :ivar logon_response: Аутентификация по логину + ОТР (опционально)
    :ivar logon_cert_response: Аутентификация по сертификату
    :ivar get_settings_response: Получение настроек обмена в
        автоматическом режиме
    """
    send_packet_response: Optional[SendPacketResponseType] = field(
        default=None,
        metadata={
            "name": "SendPacketResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    get_packet_list_response: Optional[GetPacketListResponseType] = field(
        default=None,
        metadata={
            "name": "GetPacketListResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    get_packet_response: Optional[Packet] = field(
        default=None,
        metadata={
            "name": "GetPacketResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    logon_response: Optional[LogonResponseType] = field(
        default=None,
        metadata={
            "name": "LogonResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    logon_cert_response: Optional[LogonCertResponseType] = field(
        default=None,
        metadata={
            "name": "LogonCertResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    get_settings_response: Optional[GetSettingsResponseType] = field(
        default=None,
        metadata={
            "name": "GetSettingsResponse",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class ResultBank:
    """
    :ivar success: Успешный ответ банка
    :ivar error: Ответ банка в случае возникновения ошибки
    :ivar format_version: Версия формата
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    success: Optional[SuccessResultType] = field(
        default=None,
        metadata={
            "name": "Success",
            "type": "Element",
        }
    )
    error: Optional[ErrorType] = field(
        default=None,
        metadata={
            "name": "Error",
            "type": "Element",
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional
from xsdata.models.datatype import XmlDate

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class BankPartyType:
    """
    :ivar bic: БИК банка
    :ivar name: Название банка
    """
    bic: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
            "length": 9,
        }
    )
    name: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "max_length": 160,
        }
    )


@dataclass
class BankType:
    """
    Реквизиты банка.

    :ivar bic: БИК банка
    :ivar name: Название банка
    :ivar city: Город (неселенный пункт) банка
    :ivar corresp_acc: Коррсчет банка
    """
    bic: Optional[str] = field(
        default=None,
        metadata={
            "name": "BIC",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "length": 9,
            "pattern": r"[0-9]{9}",
        }
    )
    name: Optional[str] = field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 160,
        }
    )
    city: Optional[str] = field(
        default=None,
        metadata={
            "name": "City",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 30,
        }
    )
    corresp_acc: Optional[str] = field(
        default=None,
        metadata={
            "name": "CorrespAcc",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 20,
        }
    )


@dataclass
class BudgetPaymentInfoType:
    """Реквизиты бюджетного документа.

    См.правила заполнения платежных поручений, утвержденные приказом
    Минфина России от 12 ноября 2013 года № 107н.

    :ivar drawer_status: Статус составителя  (поле 101).
    :ivar cbc: Код бюджетной классификации (КБК) в соответствии с
        классификацией доходов бюджетов РФ (поле 104).
    :ivar oktmo: Значение кода ОКТМО муниципального образования или 0
        (ноль) (поле 105).
    :ivar reason: Основание налогового платежа или 0 (ноль) (поле 106).
    :ivar tax_period: Налоговый период или 0 (ноль) / код таможенного
        органа (поле 107).
    :ivar doc_no: Номер налогового документа (поле 108).
    :ivar doc_date: Дата налогового документа или 0 (ноль) (поле 109).
    :ivar pay_type: Код выплат (поле 110).
    """
    drawer_status: Optional[str] = field(
        default=None,
        metadata={
            "name": "DrawerStatus",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 2,
        }
    )
    cbc: Optional[str] = field(
        default=None,
        metadata={
            "name": "CBC",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 20,
        }
    )
    oktmo: Optional[str] = field(
        default=None,
        metadata={
            "name": "OKTMO",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 11,
        }
    )
    reason: Optional[str] = field(
        default=None,
        metadata={
            "name": "Reason",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 2,
        }
    )
    tax_period: Optional[str] = field(
        default=None,
        metadata={
            "name": "TaxPeriod",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 10,
        }
    )
    doc_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 15,
        }
    )
    doc_date: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 10,
        }
    )
    pay_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "PayType",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 2,
        }
    )


@dataclass
class CustomerPartyType:
    """
    :ivar id: Идентификатор клиента, как он задан на стороне банка
    :ivar name: Наименование клиента
    :ivar inn: ИНН клиента
    :ivar kpp: КПП клиента
    """
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
            "min_length": 1,
            "max_length": 50,
        }
    )
    name: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "max_length": 160,
        }
    )
    inn: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "min_length": 10,
            "max_length": 12,
        }
    )
    kpp: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "length": 9,
        }
    )


@dataclass
class DigestType:
    """
    :ivar data: Данные дайджеста в base64
    """
    data: Optional["DigestType.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )

    @dataclass
    class Data:
        """
        :ivar value:
        :ivar algorithm_version: Версия алгоритма формирования дайджеста
        """
        value: Optional[bytes] = field(
            default=None,
            metadata={
                "required": True,
                "format": "base64",
            }
        )
        algorithm_version: Optional[str] = field(
            default=None,
            metadata={
                "name": "algorithmVersion",
                "type": "Attribute",
                "required": True,
                "max_length": 12,
            }
        )


@dataclass
class ErrorType:
    """
    :ivar code: Код ошибки, как он задан в описании к стандарту
    :ivar description: Описание ошибки, как оно задано в описании к
        стандарту
    :ivar more_info: Подробное пояснение к ошибке для пользователя
    """
    code: Optional[str] = field(
        default=None,
        metadata={
            "name": "Code",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "length": 4,
        }
    )
    description: Optional[str] = field(
        default=None,
        metadata={
            "name": "Description",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "max_length": 255,
        }
    )
    more_info: Optional[str] = field(
        default=None,
        metadata={
            "name": "MoreInfo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class SignatureType:
    """
    Электронная подпись.

    :ivar signed_data: Электронная подпись
    :ivar x509_issuer_name: Имя издателя сертификата открытого ключа ЭП
        (значение атрибута "CN").
    :ivar x509_serial_number: Серийный номер сертификата открытого ключа
        ЭП
    """
    signed_data: Optional[bytes] = field(
        default=None,
        metadata={
            "name": "SignedData",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "format": "base64",
        }
    )
    x509_issuer_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "x509IssuerName",
            "type": "Attribute",
            "required": True,
        }
    )
    x509_serial_number: Optional[bytes] = field(
        default=None,
        metadata={
            "name": "x509SerialNumber",
            "type": "Attribute",
            "required": True,
            "format": "base16",
        }
    )


class StatementKindType(Enum):
    """
    Тип выписки банка.

    :cvar VALUE_0: Окончательная выписка
    :cvar VALUE_1: Промежуточная выписка
    :cvar VALUE_2: Текущий остаток на счете
    """
    VALUE_0 = "0"
    VALUE_1 = "1"
    VALUE_2 = "2"


@dataclass
class StatusType:
    """
    :ivar code: Код статуса, как он задан в описанию к стандарту
    :ivar name: Наименование статуса на стороне банка
    :ivar more_info: Дополнительная информация к статусу
    """
    code: Optional[str] = field(
        default=None,
        metadata={
            "name": "Code",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "length": 2,
        }
    )
    name: Optional[str] = field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 25,
        }
    )
    more_info: Optional[str] = field(
        default=None,
        metadata={
            "name": "MoreInfo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class CustomerDetailsType:
    """
    Реквизиты налогоплательщика.

    :ivar name: Наименование налогоплательщика
    :ivar inn: Идентификационный номера налогоплательщика (ИНН)
    :ivar kpp: Для платежей в бюджет - указывать обязательно
    :ivar account: Расчетный счет клиента в его банке, независимо от
        того, прямые расчеты у этого банка или нет. Номер счета может не
        указываться в следующих случаях: в распоряжении, если
        получателем средств является кредитная организация, филиал
        кредитной организации, в том числе в целях выдачи наличных
        денежных средств получателю средств - физическому лицу без
        открытия банковского счета; в платежном поручении на общую сумму
        с реестром, в котором указаны получатели средств, обслуживаемые
        одним банком, составляемом плательщиком; в платежном поручении
        на общую сумму с реестром, в котором указаны плательщики,
        обслуживаемые одним банком, и получатели средств, обслуживаемые
        другим банком, составляемом банком плательщика
    :ivar bank: Реквизиты банка
    """
    name: Optional[str] = field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    inn: Optional[str] = field(
        default=None,
        metadata={
            "name": "INN",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    kpp: Optional[str] = field(
        default=None,
        metadata={
            "name": "KPP",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 9,
        }
    )
    account: Optional[str] = field(
        default=None,
        metadata={
            "name": "Account",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 20,
        }
    )
    bank: Optional[BankType] = field(
        default=None,
        metadata={
            "name": "Bank",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )


@dataclass
class MemOrderApp:
    """
    Данные мемориального ордера.

    :ivar doc_no: Номер документа (поле 3).
    :ivar doc_date: Дата составления (поле 4).
    :ivar spare_field5: Свободное поле (поле 5)
    :ivar author: Составитель (поле 6).
    :ivar account_name_debit: Наименование счета по дебету (поле 7)
    :ivar account_debit: Счет по дебету (поле 8)
    :ivar sum: Сумма документа (поле 9).
    :ivar spare_field9a: Свободное поле (поле 9a)
    :ivar account_name_credit: Наименование счета по кредиту (поле 10)
    :ivar account_credit: Счет по кредиту (поле 11)
    :ivar partial_transition_kind: Шифр документа (поле 13).
    :ivar spare_field14: Свободное поле (поле 14)
    :ivar spare_field15: Свободное поле (поле 15)
    :ivar transition_content: Содержание операции (поле 16).
    :ivar spare_field20: Свободное поле (поле 20)
    """
    doc_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    doc_date: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "DocDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    spare_field5: Optional[str] = field(
        default=None,
        metadata={
            "name": "SpareField5",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    author: Optional["MemOrderApp.Author"] = field(
        default=None,
        metadata={
            "name": "Author",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    account_name_debit: Optional[str] = field(
        default=None,
        metadata={
            "name": "AccountNameDebit",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    account_debit: Optional[str] = field(
        default=None,
        metadata={
            "name": "AccountDebit",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 20,
        }
    )
    sum: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "Sum",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "total_digits": 18,
            "fraction_digits": 2,
        }
    )
    spare_field9a: Optional[str] = field(
        default=None,
        metadata={
            "name": "SpareField9a",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    account_name_credit: Optional[str] = field(
        default=None,
        metadata={
            "name": "AccountNameCredit",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    account_credit: Optional[str] = field(
        default=None,
        metadata={
            "name": "AccountCredit",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 20,
        }
    )
    partial_transition_kind: Optional[str] = field(
        default=None,
        metadata={
            "name": "PartialTransitionKind",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 2,
        }
    )
    spare_field14: Optional[str] = field(
        default=None,
        metadata={
            "name": "SpareField14",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    spare_field15: Optional[str] = field(
        default=None,
        metadata={
            "name": "SpareField15",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    transition_content: Optional[str] = field(
        default=None,
        metadata={
            "name": "TransitionContent",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    spare_field20: Optional[str] = field(
        default=None,
        metadata={
            "name": "SpareField20",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )

    @dataclass
    class Author(BankType):
        """
        :ivar branch: Отделение банка
        """
        branch: Optional[str] = field(
            default=None,
            metadata={
                "name": "Branch",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )


@dataclass
class OtherCustomerDetailsType:
    """
    Реквизиты прочих налогоплательщиков.

    :ivar name: Наименование налогоплательщика
    :ivar inn: Идентификационный номера налогоплательщика (ИНН)
    :ivar kpp: Для платежей в бюджет - указывать обязательно
    :ivar account: Расчетный счет клиента в его банке, независимо от
        того, прямые расчеты у этого банка или нет
    :ivar bank: Реквизиты банка
    """
    name: Optional[str] = field(
        default=None,
        metadata={
            "name": "Name",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    inn: Optional[str] = field(
        default=None,
        metadata={
            "name": "INN",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    kpp: Optional[str] = field(
        default=None,
        metadata={
            "name": "KPP",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 9,
        }
    )
    account: Optional[str] = field(
        default=None,
        metadata={
            "name": "Account",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "min_length": 1,
            "max_length": 20,
        }
    )
    bank: Optional[BankType] = field(
        default=None,
        metadata={
            "name": "Bank",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class ParticipantType:
    """
    Одна из сторон, принимающая участие в обмене электронными документами
    (Участник)

    :ivar customer: Клиент
    :ivar bank: Банк
    """
    customer: Optional[CustomerPartyType] = field(
        default=None,
        metadata={
            "name": "Customer",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    bank: Optional[BankPartyType] = field(
        default=None,
        metadata={
            "name": "Bank",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class ResultStatusType:
    """
    :ivar error: Ответ в случае возникновения ошибки
    :ivar status: Успешный ответ
    """
    error: Optional[ErrorType] = field(
        default=None,
        metadata={
            "name": "Error",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    status: Optional[StatusType] = field(
        default=None,
        metadata={
            "name": "Status",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class OtherPaymentDataType:
    """
    Реквизиты иных банковских документов.

    :ivar doc_no: Номер документа
    :ivar doc_date: Дата составления
    :ivar sum: Сумма документа
    :ivar payer: Плательщик
    :ivar payee: Получатель
    :ivar transition_kind: Вид операции
    :ivar code: Уникальный идентификатор платежа
    :ivar purpose: Назначение
    """
    doc_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    doc_date: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "DocDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    sum: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "Sum",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "total_digits": 18,
            "fraction_digits": 2,
        }
    )
    payer: Optional[OtherCustomerDetailsType] = field(
        default=None,
        metadata={
            "name": "Payer",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    payee: Optional[OtherCustomerDetailsType] = field(
        default=None,
        metadata={
            "name": "Payee",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    transition_kind: Optional[str] = field(
        default=None,
        metadata={
            "name": "TransitionKind",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 2,
        }
    )
    code: Optional[str] = field(
        default=None,
        metadata={
            "name": "Code",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 25,
        }
    )
    purpose: Optional[str] = field(
        default=None,
        metadata={
            "name": "Purpose",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class PaymentDataType:
    """
    Данные платежного документа.

    :ivar doc_no: Номер документа (поле 3).
    :ivar doc_date: Дата составления (поле 4).
    :ivar sum: Сумма документа (поле 7).
    :ivar payer: Плательщик (поля 8, 9, 10, 11, 12, 60, 102).
    :ivar payee: Получатель (поля 13, 14, 15, 16, 17, 61, 103).
    :ivar payment_kind: Вид платежа (поле 5). Указывается "срочно",
        "телеграфом",  "почтой",   иное значение в порядке,
        установленном  банком.
    :ivar transition_kind: Вид операции (поле 18). Указывается условное
        цифровое обозначение документа, согласно установленного ЦБР
        перечня условных обозначений (шифров) документов, проводимых по
        счетам в кредитных организациях.
    :ivar priority: Очередность платежа (поле 21).
    :ivar code: Уникальный идентификатор платежа (поле 22). С 31 марта
        2014 года согласно Указанию N 3025-У ЦБР.
    :ivar income_type_code: Код вида дохода (поле 20) согласно Указанию
        5286-У ЦБРФ
    :ivar purpose: Назначение платежа (поле 24).
    """
    doc_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    doc_date: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "DocDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    sum: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "Sum",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "total_digits": 18,
            "fraction_digits": 2,
        }
    )
    payer: Optional[CustomerDetailsType] = field(
        default=None,
        metadata={
            "name": "Payer",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    payee: Optional[CustomerDetailsType] = field(
        default=None,
        metadata={
            "name": "Payee",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    payment_kind: Optional[str] = field(
        default=None,
        metadata={
            "name": "PaymentKind",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 15,
        }
    )
    transition_kind: Optional[str] = field(
        default=None,
        metadata={
            "name": "TransitionKind",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 2,
        }
    )
    priority: Optional[str] = field(
        default=None,
        metadata={
            "name": "Priority",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 1,
        }
    )
    code: Optional[str] = field(
        default=None,
        metadata={
            "name": "Code",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 25,
        }
    )
    income_type_code: Optional[str] = field(
        default=None,
        metadata={
            "name": "IncomeTypeCode",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 1,
        }
    )
    purpose: Optional[str] = field(
        default=None,
        metadata={
            "name": "Purpose",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "max_length": 210,
        }
    )


@dataclass
class BankOrderApp(PaymentDataType):
    """
    Данные банковского ордера.
    """


@dataclass
class CashContributionType(OtherPaymentDataType):
    """
    Данные объявления на взнос наличными.

    :ivar person: От кого
    :ivar symbol: Указываются цифрами символы, предусмотренные
        отчетностью по форме 0409202, в соответствии с Указанием Банка
        России N 2332-У
    :ivar source: Указываются источники поступления наличных денег в
        соответствии с содержанием символов отчетности по форме 0409202
        и содержанием операции
    """
    person: Optional["CashContributionType.Person"] = field(
        default=None,
        metadata={
            "name": "Person",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    symbol: Optional[str] = field(
        default=None,
        metadata={
            "name": "Symbol",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 10,
        }
    )
    source: Optional[str] = field(
        default=None,
        metadata={
            "name": "Source",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 255,
        }
    )

    @dataclass
    class Person:
        """
        :ivar full_name: ФИО вносителя
        :ivar identity_document: Документ, удостоверяющий личность
        """
        full_name: Optional[str] = field(
            default=None,
            metadata={
                "name": "FullName",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )
        identity_document: Optional[str] = field(
            default=None,
            metadata={
                "name": "IdentityDocument",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )


@dataclass
class CheckType(OtherPaymentDataType):
    """
    Данные денежного чека.

    :ivar person: Кому
    :ivar data_printing: Данные бумажной формы чека
    :ivar details: Направления и суммы выдачи
    """
    person: Optional["CheckType.Person"] = field(
        default=None,
        metadata={
            "name": "Person",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    data_printing: Optional["CheckType.DataPrinting"] = field(
        default=None,
        metadata={
            "name": "DataPrinting",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    details: List["CheckType.Details"] = field(
        default_factory=list,
        metadata={
            "name": "Details",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )

    @dataclass
    class Person:
        """
        :ivar full_name: ФИО получателя
        :ivar identity_document: Документ, удостоверяющий личность
        """
        full_name: Optional[str] = field(
            default=None,
            metadata={
                "name": "FullName",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )
        identity_document: Optional[str] = field(
            default=None,
            metadata={
                "name": "IdentityDocument",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )

    @dataclass
    class DataPrinting:
        """
        :ivar check_series: Серия чека
        :ivar check_number: Номер чека
        """
        check_series: Optional[str] = field(
            default=None,
            metadata={
                "name": "CheckSeries",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )
        check_number: Optional[str] = field(
            default=None,
            metadata={
                "name": "CheckNumber",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )

    @dataclass
    class Details:
        """
        :ivar symbol: Указываются цифрами символы, предусмотренные
            отчетностью по форме 0409202, в соответствии с Указанием
            Банка России N 2332-У
        :ivar purpose: Указываются направления (цели) выдачи наличных
            денег в соответствии с содержанием символов отчетности по
            форме 0409202 и содержанием операции
        :ivar sum: Сумма расходов
        """
        symbol: Optional[str] = field(
            default=None,
            metadata={
                "name": "Symbol",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "required": True,
                "max_length": 10,
            }
        )
        purpose: Optional[str] = field(
            default=None,
            metadata={
                "name": "Purpose",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "max_length": 255,
            }
        )
        sum: Optional[Decimal] = field(
            default=None,
            metadata={
                "name": "Sum",
                "type": "Element",
                "namespace": "http://directbank.1c.ru/XMLSchema",
                "required": True,
                "total_digits": 18,
                "fraction_digits": 2,
            }
        )


@dataclass
class CollectionOrderApp(PaymentDataType):
    """
    Данные инкассового поручения.

    :ivar budget_payment_info: Реквизиты бюджетного документа.
        См.правила заполнения платежных поручений, утвержденные приказом
        Минфина России от 12 ноября 2013 года № 107н.
    """
    budget_payment_info: Optional[BudgetPaymentInfoType] = field(
        default=None,
        metadata={
            "name": "BudgetPaymentInfo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class PayDocRuApp(PaymentDataType):
    """
    Данные платежного поручения.

    :ivar budget_payment_info: Реквизиты бюджетного документа.
        См.правила заполнения платежных поручений, утвержденные приказом
        Минфина России от 12 ноября 2013 года № 107н.
    """
    budget_payment_info: Optional[BudgetPaymentInfoType] = field(
        default=None,
        metadata={
            "name": "BudgetPaymentInfo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class PayRequestApp(PaymentDataType):
    """
    Данные платежного требования.

    :ivar payment_condition: Условие оплаты (поле 35): 1 - заранее
        данный акцепт плательщика; 2 - требуется получение акцепта
        плательщика.
    :ivar accept_term: Срок для акцепта (поле 36): количество дней.
    :ivar doc_dispatch_date: Дата отсылки (вручения) плательщику
        предусмотренных договором документов (поле 37).
    """
    payment_condition: Optional[str] = field(
        default=None,
        metadata={
            "name": "PaymentCondition",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
            "length": 1,
        }
    )
    accept_term: Optional[int] = field(
        default=None,
        metadata={
            "name": "AcceptTerm",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    doc_dispatch_date: Optional[str] = field(
        default=None,
        metadata={
            "name": "DocDispatchDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )


@dataclass
class PaymentOrderApp(PaymentDataType):
    """
    Данные платежного ордера.

    :ivar transition_content: Содержание операции (поле 70).
    :ivar partial_payment_no: Номер частичного платежа (поле 38).
    :ivar partial_transition_kind: Шифр платежного документа (поле 39).
    :ivar sum_residual_payment: Сумма остатка платежа (поле 42).
    :ivar partial_doc_no: Номер платежного документа (поле 40).
    :ivar partial_doc_date: Дата платежного документа (поле 41).
    :ivar budget_payment_info: Реквизиты бюджетного документа.
        См.правила заполнения платежных поручений, утвержденные приказом
        Минфина России от 12 ноября 2013 года № 107н.
    """
    transition_content: Optional[str] = field(
        default=None,
        metadata={
            "name": "TransitionContent",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 16,
        }
    )
    partial_payment_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "PartialPaymentNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 3,
        }
    )
    partial_transition_kind: Optional[str] = field(
        default=None,
        metadata={
            "name": "PartialTransitionKind",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "length": 2,
        }
    )
    sum_residual_payment: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "SumResidualPayment",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "total_digits": 18,
            "fraction_digits": 2,
        }
    )
    partial_doc_no: Optional[str] = field(
        default=None,
        metadata={
            "name": "PartialDocNo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "max_length": 6,
        }
    )
    partial_doc_date: Optional[str] = field(
        default=None,
        metadata={
            "name": "PartialDocDate",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    budget_payment_info: Optional[BudgetPaymentInfoType] = field(
        default=None,
        metadata={
            "name": "BudgetPaymentInfo",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )



from dataclasses import dataclass, field
from typing import Optional
from xsdata.models.datatype import XmlDateTime

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class X509Data:
    """
    Описание набора данных по сертификату.

    :ivar x509_issuer_name: Имя издателя сертификата электронной подписи
        (значение атрибута"CN").
    :ivar x509_serial_number: Серийный номер сертификата электронной
        подписи
    :ivar x509_certificate: Двоичные данные сертификата электронной
        подписи
    :ivar id: Идентификатор набора данных
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """
    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    x509_issuer_name: Optional[str] = field(
        default=None,
        metadata={
            "name": "X509IssuerName",
            "type": "Element",
            "required": True,
        }
    )
    x509_serial_number: Optional[bytes] = field(
        default=None,
        metadata={
            "name": "X509SerialNumber",
            "type": "Element",
            "required": True,
            "format": "base16",
        }
    )
    x509_certificate: Optional[bytes] = field(
        default=None,
        metadata={
            "name": "X509Certificate",
            "type": "Element",
            "required": True,
            "format": "base64",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )



from dataclasses import dataclass, field
from typing import Optional
from xsdata.models.datatype import XmlDateTime
from ExchCommon import (
    BankPartyType,
    CustomerPartyType,
    DigestType,
    PayRequestApp,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class PayRequest:
    """
    Платежное требование.

    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar data: Данные платежного требования
    :ivar digest: Дайджест электронного документа
    :ivar id: Идентификатор требования
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[CustomerPartyType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[BankPartyType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    data: Optional[PayRequestApp] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "required": True,
        }
    )
    digest: Optional[DigestType] = field(
        default=None,
        metadata={
            "name": "Digest",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional
from xsdata.models.datatype import XmlDate, XmlDateTime
from ExchCommon import (
    BankOrderApp,
    BankPartyType,
    BankType,
    CashContributionType,
    CheckType,
    CollectionOrderApp,
    CustomerPartyType,
    MemOrderApp,
    OtherPaymentDataType,
    PayDocRuApp,
    PayRequestApp,
    PaymentOrderApp,
    StatementKindType,
    StatusType,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


class OperationInfoDc(Enum):
    """
    :cvar VALUE_1: Операция по дебету
    :cvar VALUE_2: Операция по кредиту
    """
    VALUE_1 = "1"
    VALUE_2 = "2"


@dataclass
class Statement:
    """
    Выписка банка по лицевому счету.

    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar data: Данные выписки по лиц.счету
    :ivar ext_idstatement_request: ID исходного запроса на выписку, если
        такой был
    :ivar id: Идентификатор выписки
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[BankPartyType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[CustomerPartyType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    data: Optional["Statement.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "required": True,
        }
    )
    ext_idstatement_request: Optional[str] = field(
        default=None,
        metadata={
            "name": "ExtIDStatementRequest",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class Data:
        """
        :ivar statement_type: Тип выписки
        :ivar date_from: Начало периода выписки
        :ivar date_to: Конец периода выписки
        :ivar account: Номер лиц.счета
        :ivar bank: Банк, в котором открыт счет
        :ivar opening_balance: Остаток на счете на начало периода
        :ivar total_debits: Общая сумма документов по дебету счета
        :ivar total_credits: Общая сумма документов по кредиту счета
        :ivar closing_balance: Остаток на счете на конец периода
        :ivar operation_info: Информация об одной операции по лицевому
            счету в выписке
        :ivar stamp: Данные штампа банка по выписке в целом
        """
        statement_type: Optional[StatementKindType] = field(
            default=None,
            metadata={
                "name": "StatementType",
                "type": "Element",
                "required": True,
            }
        )
        date_from: Optional[XmlDateTime] = field(
            default=None,
            metadata={
                "name": "DateFrom",
                "type": "Element",
            }
        )
        date_to: Optional[XmlDateTime] = field(
            default=None,
            metadata={
                "name": "DateTo",
                "type": "Element",
                "required": True,
            }
        )
        account: Optional[str] = field(
            default=None,
            metadata={
                "name": "Account",
                "type": "Element",
                "required": True,
                "min_length": 1,
                "max_length": 20,
            }
        )
        bank: Optional[BankType] = field(
            default=None,
            metadata={
                "name": "Bank",
                "type": "Element",
                "required": True,
            }
        )
        opening_balance: Optional[Decimal] = field(
            default=None,
            metadata={
                "name": "OpeningBalance",
                "type": "Element",
                "total_digits": 18,
                "fraction_digits": 2,
            }
        )
        total_debits: Optional[Decimal] = field(
            default=None,
            metadata={
                "name": "TotalDebits",
                "type": "Element",
                "total_digits": 18,
                "fraction_digits": 2,
            }
        )
        total_credits: Optional[Decimal] = field(
            default=None,
            metadata={
                "name": "TotalCredits",
                "type": "Element",
                "total_digits": 18,
                "fraction_digits": 2,
            }
        )
        closing_balance: Optional[Decimal] = field(
            default=None,
            metadata={
                "name": "ClosingBalance",
                "type": "Element",
                "required": True,
                "total_digits": 18,
                "fraction_digits": 2,
            }
        )
        operation_info: List["Statement.Data.OperationInfo"] = field(
            default_factory=list,
            metadata={
                "name": "OperationInfo",
                "type": "Element",
            }
        )
        stamp: Optional["Statement.Data.Stamp"] = field(
            default=None,
            metadata={
                "name": "Stamp",
                "type": "Element",
            }
        )

        @dataclass
        class OperationInfo:
            """
            :ivar pay_doc: Данные платежного документа
            :ivar dc: Признак дебета/кредита: 1 - дебет, 2 - кредит
            :ivar date: Дата проводки документа по лиц.счету
            :ivar ext_id: ID исходного платежного документа плательщика
            :ivar stamp: Данные штампа банка по каждому платежному
                документу
            """
            pay_doc: Optional["Statement.Data.OperationInfo.PayDoc"] = field(
                default=None,
                metadata={
                    "name": "PayDoc",
                    "type": "Element",
                    "required": True,
                }
            )
            dc: Optional[OperationInfoDc] = field(
                default=None,
                metadata={
                    "name": "DC",
                    "type": "Element",
                    "required": True,
                    "length": 1,
                }
            )
            date: Optional[XmlDate] = field(
                default=None,
                metadata={
                    "name": "Date",
                    "type": "Element",
                    "required": True,
                }
            )
            ext_id: Optional[str] = field(
                default=None,
                metadata={
                    "name": "ExtID",
                    "type": "Element",
                }
            )
            stamp: Optional["Statement.Data.OperationInfo.Stamp"] = field(
                default=None,
                metadata={
                    "name": "Stamp",
                    "type": "Element",
                }
            )

            @dataclass
            class PayDoc:
                """
                :ivar pay_doc_ru: Данные платежного поручения
                :ivar pay_request: Данные платежного требования
                :ivar collection_order: Данные инкассового поручения
                :ivar payment_order: Данные платежного ордера
                :ivar bank_order: Данные банковского ордера
                :ivar mem_order: Данные мемориального ордера
                :ivar inner_doc: Данные внутр.банковского документа
                :ivar cash_contribution: Данные объявления на взнос
                    наличными
                :ivar check: Данные денежного чека
                :ivar id: ID платежного документа в банке
                :ivar doc_kind: Код вида электронного документа, как он
                    задан в описании к стандарту
                """
                pay_doc_ru: Optional[PayDocRuApp] = field(
                    default=None,
                    metadata={
                        "name": "PayDocRu",
                        "type": "Element",
                    }
                )
                pay_request: Optional[PayRequestApp] = field(
                    default=None,
                    metadata={
                        "name": "PayRequest",
                        "type": "Element",
                    }
                )
                collection_order: Optional[CollectionOrderApp] = field(
                    default=None,
                    metadata={
                        "name": "CollectionOrder",
                        "type": "Element",
                    }
                )
                payment_order: Optional[PaymentOrderApp] = field(
                    default=None,
                    metadata={
                        "name": "PaymentOrder",
                        "type": "Element",
                    }
                )
                bank_order: Optional[BankOrderApp] = field(
                    default=None,
                    metadata={
                        "name": "BankOrder",
                        "type": "Element",
                    }
                )
                mem_order: Optional[MemOrderApp] = field(
                    default=None,
                    metadata={
                        "name": "MemOrder",
                        "type": "Element",
                    }
                )
                inner_doc: Optional["Statement.Data.OperationInfo.PayDoc.InnerDoc"] = field(
                    default=None,
                    metadata={
                        "name": "InnerDoc",
                        "type": "Element",
                    }
                )
                cash_contribution: Optional[CashContributionType] = field(
                    default=None,
                    metadata={
                        "name": "CashContribution",
                        "type": "Element",
                    }
                )
                check: Optional[CheckType] = field(
                    default=None,
                    metadata={
                        "name": "Check",
                        "type": "Element",
                    }
                )
                id: Optional[str] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                    }
                )
                doc_kind: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "docKind",
                        "type": "Attribute",
                        "required": True,
                        "length": 2,
                    }
                )

                @dataclass
                class InnerDoc(OtherPaymentDataType):
                    """
                    :ivar inner_doc_kind: Название типа
                        внутр.банковского документа
                    """
                    inner_doc_kind: Optional[str] = field(
                        default=None,
                        metadata={
                            "name": "InnerDocKind",
                            "type": "Element",
                            "required": True,
                            "max_length": 255,
                        }
                    )

            @dataclass
            class Stamp(BankType):
                """
                :ivar branch: Отделение банка
                :ivar status: Статус платежного документа в банке
                """
                branch: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "Branch",
                        "type": "Element",
                        "max_length": 255,
                    }
                )
                status: Optional[StatusType] = field(
                    default=None,
                    metadata={
                        "name": "Status",
                        "type": "Element",
                        "required": True,
                    }
                )

        @dataclass
        class Stamp(BankType):
            """
            :ivar branch: Отделение банка
            """
            branch: Optional[str] = field(
                default=None,
                metadata={
                    "name": "Branch",
                    "type": "Element",
                    "max_length": 255,
                }
            )



from dataclasses import dataclass, field
from enum import Enum
from typing import List, Optional
from xsdata.models.datatype import XmlDateTime
from ExchCommon import (
    BankPartyType,
    CustomerPartyType,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


class DataEncoding(Enum):
    UTF_8 = "UTF-8"


@dataclass
class Settings:
    """
    Настройки обмена клиента с банком.

    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar data: Параметры обмена
    :ivar id: Идентификатор набора данных
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[BankPartyType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[CustomerPartyType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    data: Optional["Settings.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "required": True,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class Data:
        """
        :ivar customer_id: Уникальный идентификатор организации в банке
        :ivar bank_server_address: Адрес ресурса банка
        :ivar format_version: Актуальная версия формата обмена данными
        :ivar encoding: Кодировка файлов обмена
        :ivar compress: Признак сжатия электронных документов при обмене
        :ivar logon: Способ аутентификации на ресурсе банка
        :ivar crypto_parameters: Настройки криптографии
        :ivar document: Настройки по видам электронных документов,
            которыми возможен обмен с банком
        :ivar receipt_statement: Параметры получения выписки в
            автоматическом режиме
        :ivar letters: Свойства писем
        """
        customer_id: Optional[str] = field(
            default=None,
            metadata={
                "name": "CustomerID",
                "type": "Element",
                "required": True,
                "min_length": 1,
                "max_length": 50,
            }
        )
        bank_server_address: Optional[str] = field(
            default=None,
            metadata={
                "name": "BankServerAddress",
                "type": "Element",
                "required": True,
                "min_length": 1,
            }
        )
        format_version: Optional[str] = field(
            default=None,
            metadata={
                "name": "FormatVersion",
                "type": "Element",
                "required": True,
                "max_length": 12,
            }
        )
        encoding: DataEncoding = field(
            default=DataEncoding.UTF_8,
            metadata={
                "name": "Encoding",
                "type": "Element",
                "required": True,
            }
        )
        compress: Optional[bool] = field(
            default=None,
            metadata={
                "name": "Compress",
                "type": "Element",
            }
        )
        logon: Optional["Settings.Data.Logon"] = field(
            default=None,
            metadata={
                "name": "Logon",
                "type": "Element",
                "required": True,
            }
        )
        crypto_parameters: Optional["Settings.Data.CryptoParameters"] = field(
            default=None,
            metadata={
                "name": "CryptoParameters",
                "type": "Element",
            }
        )
        document: List["Settings.Data.Document"] = field(
            default_factory=list,
            metadata={
                "name": "Document",
                "type": "Element",
                "min_occurs": 1,
            }
        )
        receipt_statement: Optional["Settings.Data.ReceiptStatement"] = field(
            default=None,
            metadata={
                "name": "ReceiptStatement",
                "type": "Element",
            }
        )
        letters: Optional["Settings.Data.Letters"] = field(
            default=None,
            metadata={
                "name": "Letters",
                "type": "Element",
            }
        )

        @dataclass
        class Logon:
            """
            :ivar login: По логину и паролю
            :ivar certificate: По сертификату электронной подписи
            """
            login: Optional["Settings.Data.Logon.Login"] = field(
                default=None,
                metadata={
                    "name": "Login",
                    "type": "Element",
                }
            )
            certificate: Optional["Settings.Data.Logon.Certificate"] = field(
                default=None,
                metadata={
                    "name": "Certificate",
                    "type": "Element",
                }
            )

            @dataclass
            class Login:
                """
                :ivar user: Логин пользователя
                """
                user: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "User",
                        "type": "Element",
                        "required": True,
                        "max_length": 50,
                    }
                )

            @dataclass
            class Certificate:
                """
                :ivar encrypting_algorithm: Алгоритм шифрования,
                    например, GOST 28147-89
                """
                encrypting_algorithm: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "EncryptingAlgorithm",
                        "type": "Element",
                        "required": True,
                        "max_length": 50,
                    }
                )

        @dataclass
        class CryptoParameters:
            """
            :ivar cspname: Имя CSP (cryptographic service provider)
            :ivar csptype: Тип CSP (cryptographic service provider)
            :ivar sign_algorithm: Алгоритм подписи, например, GOST R
                34.10-2001
            :ivar hash_algorithm: Алгоритм хэширования, например, GOST R
                34.11-94
            :ivar encrypted: Применение шифрования данных на прикладном
                уровне
            :ivar bank_trusted_root_certificate: Доверенный корневой
                сертификат УЦ банка
            :ivar bank_certificate: Сертификат электронной подписи банка
            :ivar customer_signature: Карточка электронных подписей
                клиента
            :ivar urladdin_info: Адрес-ссылка, откуда надо будет
                загружаться файл описания внешн.модуля, если он
                используется в обмене
            """
            cspname: Optional[str] = field(
                default=None,
                metadata={
                    "name": "CSPName",
                    "type": "Element",
                    "required": True,
                    "max_length": 256,
                }
            )
            csptype: Optional[int] = field(
                default=None,
                metadata={
                    "name": "CSPType",
                    "type": "Element",
                    "required": True,
                }
            )
            sign_algorithm: Optional[str] = field(
                default=None,
                metadata={
                    "name": "SignAlgorithm",
                    "type": "Element",
                    "required": True,
                    "max_length": 50,
                }
            )
            hash_algorithm: Optional[str] = field(
                default=None,
                metadata={
                    "name": "HashAlgorithm",
                    "type": "Element",
                    "required": True,
                    "max_length": 50,
                }
            )
            encrypted: Optional["Settings.Data.CryptoParameters.Encrypted"] = field(
                default=None,
                metadata={
                    "name": "Encrypted",
                    "type": "Element",
                }
            )
            bank_trusted_root_certificate: Optional[bytes] = field(
                default=None,
                metadata={
                    "name": "BankTrustedRootCertificate",
                    "type": "Element",
                    "format": "base64",
                }
            )
            bank_certificate: Optional[bytes] = field(
                default=None,
                metadata={
                    "name": "BankCertificate",
                    "type": "Element",
                    "format": "base64",
                }
            )
            customer_signature: Optional["Settings.Data.CryptoParameters.CustomerSignature"] = field(
                default=None,
                metadata={
                    "name": "CustomerSignature",
                    "type": "Element",
                    "required": True,
                }
            )
            urladdin_info: Optional[str] = field(
                default=None,
                metadata={
                    "name": "URLAddinInfo",
                    "type": "Element",
                }
            )

            @dataclass
            class CustomerSignature:
                """
                :ivar group_signatures: Группа электронных подписей
                """
                group_signatures: List["Settings.Data.CryptoParameters.CustomerSignature.GroupSignatures"] = field(
                    default_factory=list,
                    metadata={
                        "name": "GroupSignatures",
                        "type": "Element",
                        "min_occurs": 1,
                    }
                )

                @dataclass
                class GroupSignatures:
                    """
                    :ivar certificate: Сертификаты электронных подписей
                        сотрудников клиента
                    :ivar number_group: Номер группы электронных
                        подписей
                    """
                    certificate: List[bytes] = field(
                        default_factory=list,
                        metadata={
                            "name": "Certificate",
                            "type": "Element",
                            "min_occurs": 1,
                            "max_occurs": 9,
                            "format": "base64",
                        }
                    )
                    number_group: Optional[int] = field(
                        default=None,
                        metadata={
                            "name": "numberGroup",
                            "type": "Attribute",
                            "required": True,
                        }
                    )

            @dataclass
            class Encrypted:
                """
                :ivar encrypt_algorithm: Алгоритм шифрования, например,
                    GOST 28147-89
                """
                encrypt_algorithm: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "EncryptAlgorithm",
                        "type": "Element",
                        "required": True,
                        "max_length": 50,
                    }
                )

        @dataclass
        class Document:
            """
            :ivar signed: Применение электронной подписи для данного
                вида электронного документа
            :ivar doc_kind: Код вида электронного документа, как он
                задан в описании к стандарту
            """
            signed: Optional["Settings.Data.Document.Signed"] = field(
                default=None,
                metadata={
                    "name": "Signed",
                    "type": "Element",
                }
            )
            doc_kind: Optional[str] = field(
                default=None,
                metadata={
                    "name": "docKind",
                    "type": "Attribute",
                    "required": True,
                    "length": 2,
                }
            )

            @dataclass
            class Signed:
                """
                :ivar rule_signatures: Правило, задающее наличие
                    электронных подписей для данного вида электронного
                    документа
                """
                rule_signatures: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "RuleSignatures",
                        "type": "Element",
                        "required": True,
                    }
                )

        @dataclass
        class ReceiptStatement:
            """
            :ivar login: Логин, по которому можно получать только
                выписку банка
            :ivar instructions: Инструкция по получению пароля для
                вышеуказанного логина
            """
            login: Optional[str] = field(
                default=None,
                metadata={
                    "name": "Login",
                    "type": "Element",
                    "required": True,
                    "max_length": 50,
                }
            )
            instructions: Optional[str] = field(
                default=None,
                metadata={
                    "name": "Instructions",
                    "type": "Element",
                    "required": True,
                }
            )

        @dataclass
        class Letters:
            """
            :ivar attachments_limit: Максимальный суммартный объем
                присоединенных файлов (в байтах)
            :ivar letter_type: Возможные типы писем
            """
            attachments_limit: Optional[int] = field(
                default=None,
                metadata={
                    "name": "AttachmentsLimit",
                    "type": "Element",
                    "required": True,
                }
            )
            letter_type: List["Settings.Data.Letters.LetterType"] = field(
                default_factory=list,
                metadata={
                    "name": "LetterType",
                    "type": "Element",
                    "min_occurs": 1,
                }
            )

            @dataclass
            class LetterType:
                """
                :ivar code: Код типа письма
                :ivar name: Наименование письма
                """
                code: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "Code",
                        "type": "Element",
                        "required": True,
                        "max_length": 2,
                    }
                )
                name: Optional[str] = field(
                    default=None,
                    metadata={
                        "name": "Name",
                        "type": "Element",
                        "required": True,
                        "max_length": 150,
                    }
                )



from dataclasses import dataclass, field
from enum import Enum
from typing import List, Optional
from xsdata.models.datatype import XmlDateTime
from ExchCommon import (
    ParticipantType,
    SignatureType,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


class ContentType(Enum):
    APPLICATION_XML = "application/xml"
    APPLICATION_OCTET_STREAM = "application/octet-stream"
    TEXT_PLAIN = "text/plain"
    TEXT_XML = "text/xml"


@dataclass
class DocumentType:
    """
    :ivar data: Данные электронного документа
    :ivar signature: Данные электронных подписей
    :ivar id: Идентификатор электронного документа
    :ivar dockind: Код вида электронного документа, как он задан в
        описаниии к стандарту
    :ivar format_version: Версия формата
    :ivar test_only: Тестовый документ
    :ivar compressed: Документ сжат
    :ivar encrypted: Документ зашифрован
    :ivar sign_response: Требуется Ответная Подпись
    :ivar notify_required: Требуется Извещение О Получении
    :ivar ext_id: ID исходного документа, если такой был
    """
    data: Optional["DocumentType.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
            "required": True,
        }
    )
    signature: List[SignatureType] = field(
        default_factory=list,
        metadata={
            "name": "Signature",
            "type": "Element",
            "namespace": "http://directbank.1c.ru/XMLSchema",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    dockind: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
            "length": 2,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    test_only: Optional[bool] = field(
        default=None,
        metadata={
            "name": "testOnly",
            "type": "Attribute",
        }
    )
    compressed: Optional[bool] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    encrypted: Optional[bool] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    sign_response: Optional[bool] = field(
        default=None,
        metadata={
            "name": "signResponse",
            "type": "Attribute",
        }
    )
    notify_required: Optional[bool] = field(
        default=None,
        metadata={
            "name": "notifyRequired",
            "type": "Attribute",
        }
    )
    ext_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "extID",
            "type": "Attribute",
        }
    )

    @dataclass
    class Data:
        """
        :ivar value:
        :ivar file_name: Имя файла
        :ivar content_type: Тип контента передаваемого файла
        """
        value: Optional[bytes] = field(
            default=None,
            metadata={
                "required": True,
                "format": "base64",
            }
        )
        file_name: Optional[str] = field(
            default=None,
            metadata={
                "name": "fileName",
                "type": "Attribute",
            }
        )
        content_type: Optional[ContentType] = field(
            default=None,
            metadata={
                "name": "contentType",
                "type": "Attribute",
            }
        )


@dataclass
class Packet:
    """
    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar document: Электронный документ
    :ivar sender_footprint:
    :ivar id: Идентификатор транспортного контейнера
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[ParticipantType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[ParticipantType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    document: List[DocumentType] = field(
        default_factory=list,
        metadata={
            "name": "Document",
            "type": "Element",
            "min_occurs": 1,
        }
    )
    sender_footprint: Optional["Packet.SenderFootprint"] = field(
        default=None,
        metadata={
            "name": "SenderFootprint",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class SenderFootprint:
        ip: List[str] = field(
            default_factory=list,
            metadata={
                "name": "IP",
                "type": "Element",
                "max_length": 39,
            }
        )
        mac: List[str] = field(
            default_factory=list,
            metadata={
                "name": "MAC",
                "type": "Element",
                "max_length": 17,
            }
        )



from dataclasses import dataclass, field
from typing import Optional
from xsdata.models.datatype import XmlDateTime
from ExchCommon import (
    BankPartyType,
    BankType,
    CustomerPartyType,
    DigestType,
    StatementKindType,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class StatementRequest:
    """
    Запрос выписки банка.

    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar data: Данные запроса
    :ivar digest: Дайджест запроса
    :ivar id: Идентификатор запроса
    :ivar format_version: Версия формата
    :ivar creation_date: Дата и время формирования
    :ivar user_agent: Наименование и версия программы
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[CustomerPartyType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[BankPartyType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    data: Optional["StatementRequest.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "required": True,
        }
    )
    digest: Optional[DigestType] = field(
        default=None,
        metadata={
            "name": "Digest",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class Data:
        """
        :ivar statement_type: Тип выписки
        :ivar date_from: Начало периода формирования выписки
        :ivar date_to: Конец периода формирования выписки
        :ivar account: Номер счета, по которому производится запрос
        :ivar bank: Банк, в котором открыт счет
        """
        statement_type: Optional[StatementKindType] = field(
            default=None,
            metadata={
                "name": "StatementType",
                "type": "Element",
                "required": True,
            }
        )
        date_from: Optional[XmlDateTime] = field(
            default=None,
            metadata={
                "name": "DateFrom",
                "type": "Element",
                "required": True,
            }
        )
        date_to: Optional[XmlDateTime] = field(
            default=None,
            metadata={
                "name": "DateTo",
                "type": "Element",
                "required": True,
            }
        )
        account: Optional[str] = field(
            default=None,
            metadata={
                "name": "Account",
                "type": "Element",
                "required": True,
                "min_length": 1,
                "max_length": 20,
            }
        )
        bank: Optional[BankType] = field(
            default=None,
            metadata={
                "name": "Bank",
                "type": "Element",
                "required": True,
            }
        )



from dataclasses import dataclass, field
from typing import List, Optional
from xsdata.models.datatype import XmlDate, XmlDateTime
from ExchCommon import (
    ParticipantType,
    SignatureType,
)

__NAMESPACE__ = "http://directbank.1c.ru/XMLSchema"


@dataclass
class Letter:
    """
    Письмо.

    :ivar sender: Отправитель
    :ivar recipient: Получатель
    :ivar data: Данные письма
    :ivar id:
    :ivar format_version:
    :ivar creation_date:
    :ivar user_agent:
    """

    class Meta:
        namespace = "http://directbank.1c.ru/XMLSchema"

    sender: Optional[ParticipantType] = field(
        default=None,
        metadata={
            "name": "Sender",
            "type": "Element",
            "required": True,
        }
    )
    recipient: Optional[ParticipantType] = field(
        default=None,
        metadata={
            "name": "Recipient",
            "type": "Element",
            "required": True,
        }
    )
    data: Optional["Letter.Data"] = field(
        default=None,
        metadata={
            "name": "Data",
            "type": "Element",
            "required": True,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "required": True,
        }
    )
    format_version: Optional[str] = field(
        default=None,
        metadata={
            "name": "formatVersion",
            "type": "Attribute",
            "required": True,
            "max_length": 12,
        }
    )
    creation_date: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "creationDate",
            "type": "Attribute",
            "required": True,
        }
    )
    user_agent: Optional[str] = field(
        default=None,
        metadata={
            "name": "userAgent",
            "type": "Attribute",
            "max_length": 100,
        }
    )

    @dataclass
    class Data:
        """
        :ivar doc_num: Номер документа
        :ivar doc_date: Дата составления
        :ivar letter_type_code: Код типа письма
        :ivar theme: Тема письма
        :ivar text: Текст письма
        :ivar attachment: Вложение
        :ivar linked_doc: Объект обсуждения. Например, платежное
            поручение или требование.
        :ivar linked_id: ID изначального письма
        :ivar correspondence_id: ID переписки
        """
        doc_num: Optional[str] = field(
            default=None,
            metadata={
                "name": "DocNum",
                "type": "Element",
                "required": True,
            }
        )
        doc_date: Optional[XmlDate] = field(
            default=None,
            metadata={
                "name": "DocDate",
                "type": "Element",
                "required": True,
            }
        )
        letter_type_code: Optional[str] = field(
            default=None,
            metadata={
                "name": "LetterTypeCode",
                "type": "Element",
                "max_length": 2,
            }
        )
        theme: Optional[str] = field(
            default=None,
            metadata={
                "name": "Theme",
                "type": "Element",
                "max_length": 100,
            }
        )
        text: Optional[str] = field(
            default=None,
            metadata={
                "name": "Text",
                "type": "Element",
                "required": True,
            }
        )
        attachment: List["Letter.Data.Attachment"] = field(
            default_factory=list,
            metadata={
                "name": "Attachment",
                "type": "Element",
            }
        )
        linked_doc: Optional["Letter.Data.LinkedDoc"] = field(
            default=None,
            metadata={
                "name": "LinkedDoc",
                "type": "Element",
            }
        )
        linked_id: Optional[str] = field(
            default=None,
            metadata={
                "name": "linkedID",
                "type": "Attribute",
            }
        )
        correspondence_id: Optional[str] = field(
            default=None,
            metadata={
                "name": "correspondenceID",
                "type": "Attribute",
            }
        )

        @dataclass
        class Attachment:
            """
            :ivar binary_file: Двоичные данные файла
            :ivar signature: Данные электронных подписей
            """
            binary_file: Optional["Letter.Data.Attachment.BinaryFile"] = field(
                default=None,
                metadata={
                    "name": "BinaryFile",
                    "type": "Element",
                    "required": True,
                }
            )
            signature: List[SignatureType] = field(
                default_factory=list,
                metadata={
                    "name": "Signature",
                    "type": "Element",
                }
            )

            @dataclass
            class BinaryFile:
                """
                :ivar value:
                :ivar id: Уникальный идентификатор вложения
                :ivar name: Полное имя файла с расширением
                :ivar extension: Расширение имени файла
                :ivar size: Размер файла в байтах
                :ivar crc: Контрольная сумма файла (алгоритм CRC32)
                :ivar creation_date: Дата создания
                """
                value: Optional[bytes] = field(
                    default=None,
                    metadata={
                        "required": True,
                        "format": "base64",
                    }
                )
                id: Optional[str] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                    }
                )
                name: Optional[str] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                        "min_length": 1,
                        "max_length": 256,
                    }
                )
                extension: Optional[str] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                        "max_length": 10,
                    }
                )
                size: Optional[int] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                    }
                )
                crc: Optional[int] = field(
                    default=None,
                    metadata={
                        "type": "Attribute",
                        "required": True,
                    }
                )
                creation_date: Optional[XmlDateTime] = field(
                    default=None,
                    metadata={
                        "name": "creationDate",
                        "type": "Attribute",
                        "required": True,
                    }
                )

        @dataclass
        class LinkedDoc:
            """
            :ivar id: Идентификатор документа
            :ivar dockind: Код вида электронного документа, как он задан
                в описаниии к стандарту
            """
            id: Optional[str] = field(
                default=None,
                metadata={
                    "type": "Attribute",
                    "required": True,
                }
            )
            dockind: Optional[str] = field(
                default=None,
                metadata={
                    "type": "Attribute",
                    "required": True,
                    "length": 2,
                }
            )
